@@ -40,7 +40,7 @@ from django.utils.translation import ugettext_lazy as _
 from django.utils.translation import ugettext
 from django.template import RequestContext
 from django.shortcuts import render_to_response
-from django.utils import simplejson
+import json as jsonlib
 from django.contrib.auth import authenticate, login
 from django.views.decorators.csrf import csrf_exempt
 from django.contrib.sites.models import Site
@@ -54,12 +54,12 @@ except:
     markdown = lambda x: x
     BIT = '<br>'
 else:
-    markdown = lambda x: _markdown(x.decode('utf-8'))
+    markdown = lambda x: _markdown(x)
     BIT = '\n'
 
 from http import JSONResponse, MESSAGES
 from conf import QUICKAPI_DEFINED_METHODS, QUICKAPI_ONLY_AUTHORIZED_USERS,\
-                 QUICKAPI_DEBUG, SITE_ID
+                 QUICKAPI_DEBUG, DEBUG, SITE_ID
 
 @csrf_exempt
 def test(request):
@@ -119,11 +119,15 @@ def get_methods(dic=QUICKAPI_DEFINED_METHODS):
                 method = None
         if method:
             text = drop_space(method.__doc__)
-            methods[key] = {
-                'method': method,
-                'doc': markdown(text),
-                'name': key
-            }
+            try:
+                text = markdown(text.decode('utf-8'))
+            except UnicodeDecodeError:
+                try:
+                    text = markdown(text)
+                except:
+                    pass
+            methods[key] = {'method': method, 'doc': text, 'name': key}
+
     return methods
 
 METHODS = get_methods()
@@ -209,14 +213,18 @@ def run(request, methods):
             username, password = _auth(request.POST)
     elif request.method == 'POST':
         try:
-            json = simplejson.loads(request.POST.get('jsonData', request.POST.keys()[0]))
+            json = jsonlib.loads(request.POST.get('jsonData', request.POST.keys()[0]))
             method = json.get('method', 'quickapi.test')
             kwargs = json.get('kwargs', _get_kwargs(json))
         except Exception as e:
-            p = '\t%s' % e
-            print colorize(p, fg='red')
-            p = '\trequest.POST\t\t== %s' % request.POST
-            print colorize(p, fg='red')
+            pe = '\t%s' % e
+            ppost = '\trequest.POST\t\t== %s' % request.POST
+            if QUICKAPI_DEBUG:
+                print colorize(pe, fg='red')
+                print colorize(ppost, fg='blue')
+            else:
+                print pe
+                print ppost
             return JSONResponse(status=400, message=unicode(e))
         else:
             if not is_authenticate:
@@ -238,7 +246,7 @@ def run(request, methods):
     try:
         real_method = methods[method]['method']
     except Exception as e:
-        if QUICKAPI_DEBUG:
+        if DEBUG:
             msg = unicode(traceback.format_exc(e))
             print msg
         else:
@@ -247,7 +255,7 @@ def run(request, methods):
     try:
         return real_method(request, **kwargs)
     except Exception as e:
-        if QUICKAPI_DEBUG:
+        if DEBUG:
             msg = unicode(traceback.format_exc(e))
             print msg
         else:
